==> haskell-cryptonite-conduit-0.2.2-163-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.2
id: cryptonite-conduit-0.2.2-5tmknFUo8SwJoFQvc1bvWJ
key: cryptonite-conduit-0.2.2-5tmknFUo8SwJoFQvc1bvWJ
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
abi: d2d7d4ff190c1a538598003ff6165417
exposed: True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit
import-dirs: /usr/lib/ghc-8.6.5/site-local/cryptonite-conduit-0.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cryptonite-conduit-0.2.2
hs-libraries: HScryptonite-conduit-0.2.2-5tmknFUo8SwJoFQvc1bvWJ
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-Fm1W7uNei6OKfQ1DCXNTzR
    conduit-extra-1.3.1.1-AngzwA8fwFjHMuGZOiitQU
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    exceptions-0.10.2-38lh9z3oeQXEUP64sSuIJH
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    resourcet-1.2.2-njuTV0kmRGB4xSgU2BFrl transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptonite-conduit-0.2.2-164-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cryptonite-conduit
version: 0.2.2
id: cryptonite-conduit-0.2.2-3CRbLeeRmqD79cEQRMKsIL
key: cryptonite-conduit-0.2.2-3CRbLeeRmqD79cEQRMKsIL
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/haskell-crypto/cryptonite-conduit
synopsis: cryptonite conduit
description:
    Conduit bridge for cryptonite
    .
    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.
category: Cryptography, Conduit
abi: b87c01d02ce59e7964179df2127468db
exposed: True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit
import-dirs: /usr/lib/ghc-8.6.5/site-local/cryptonite-conduit-0.2.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/cryptonite-conduit-0.2.2
hs-libraries: HScryptonite-conduit-0.2.2-3CRbLeeRmqD79cEQRMKsIL
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    conduit-1.3.1.1-Fm1W7uNei6OKfQ1DCXNTzR
    conduit-extra-1.3.1.1-72QlKWyxYxe2Qs3VC2WoC0
    cryptonite-0.25-DtJYWQJTat6yrCxAz9OOT
    exceptions-0.10.2-38lh9z3oeQXEUP64sSuIJH
    memory-0.14.18-IbWiQctDwmh73RXfnLR7k6
    resourcet-1.2.2-njuTV0kmRGB4xSgU2BFrl transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock
haddock-html: /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
